local harbour = ...

--------------------------------------------------------------------------
-- Apply building asset processor
harbour:registerAssetProcessor("models/lightTower.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register LargeGate prefab nodes
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_0_Light_RootPart", "HARBOUR_LIGHT_TOWER_ROOT_PREFAB")
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_1_Light_Tiling1Part", "HARBOUR_LIGHT_TOWER_TILING1_PREFAB")
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_2_Light_Tiling2Part", "HARBOUR_LIGHT_TOWER_TILING2_PREFAB")
harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/step_3_Light_TopPart", "HARBOUR_LIGHT_TOWER_TOP_PREFAB")
--------------------------------------------------------------------------

-- Create default building part registering function 
function registerDefaultBuildingPart2(_nodePrefix)
	harbour:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		    },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		    }
	        },
	        EstateSplendor = {
		    { Estate = "KINGDOM", Quantity = 0.1 }
	        }
	})
end

local defaultNodePrefixList2 = {
	"HARBOUR_LIGHT_TOWER_TOP",
	"HARBOUR_LIGHT_TOWER_TILING1",
	"HARBOUR_LIGHT_TOWER_TILING2"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList2) do
	registerDefaultBuildingPart2(nodePrefix)
end

-- Register the stone gate set circular tower root part
harbour:register({
	DataType = "BUILDING_PART",
	Id = "HARBOUR_LIGHT_TOWER_ROOT_PART",
	Name = "HARBOUR_LIGHT_TOWER_ROOT_NAME",
	Description = "HARBOUR_LIGHT_TOWER_ROOT_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = "HARBOUR_LIGHT_TOWER_ROOT_PREFAB",
		EndPart = "HARBOUR_LIGHT_TOWER_TOP_PART",
		FillerList = {
			"HARBOUR_LIGHT_TOWER_TILING2_PART"
                },
		BasementFillerList = {
			"HARBOUR_LIGHT_TOWER_TILING1_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true,
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	},
        VillagerCapacity = 9
})

--------------------------------------------------------------------------
-- Register grass clearing components

harbour:registerPrefabComponent("models/lightTower.fbx/Prefab/lightTower/step_0_Light_RootPart", {
	DataType = "COMP_DIRT_CIRCLE",
	HardRadius = 4,
        SoftRadius = 4,
        IsPermanent = true
})

-- Override building part components properties (generated by the building asset processor) to add building zones
harbour:registerPrefabComponent("models/lightTower.fbx/Prefab/lightTower/step_0_Light_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZoneData = {
            DataType = "BUILDING_ZONE", 
            Polygon = polygon.createCircle( 3.3, { 0, 0 }, 16 )
        }
})

function registerRoofPart(_nameFbx, _nameAsset)
    harbour:registerAssetId("models/lightTower.fbx/Prefab/lightTower/" .. _nameFbx .. "Part", "HARBOUR_" .. _nameAsset .. "_PREFAB")

-- Register the stone gate set decoration roof part
    harbour:register({
	DataType = "BUILDING_PART",
	Id = "HARBOUR_" .. _nameAsset .. "_PART",
	Name = "HARBOUR_" .. _nameAsset .. "_NAME",
	Description = "HARBOUR_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "HARBOUR_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 5 }
		}
	}
    })

    harbour:registerPrefabComponent("models/lightTower.fbx/Prefab/lightTower/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the roofs)
	BuildingZone = { 4, 4 }
    })
end

registerRoofPart( "LightRoof", "LIGHT_ROOF" )
registerRoofPart( "LightRoofB", "LIGHT_ROOF_B" )

-- Register the boat part
-- Apply building asset processor
harbour:registerAssetProcessor("models/boat2.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register IDs for all prefab nodes referenced here
harbour:registerAssetId("models/boat2.fbx/Prefab/harbour/boatPart", "HARBOUR_BOAT_PREFAB")

harbour:register({
	DataType = "BUILDING_PART",
	Id = "HARBOUR_BOAT_PART",
	Name = "HARBOUR_BOAT_NAME",
	Description = "HARBOUR_BOAT_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "HARBOUR_BOAT_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = 5 }
		}
	}
})

    --------------------------------------------------------------------------
    -- Register waterline component
    harbour:registerPrefabComponent("models/boat2.fbx/Prefab/harbour/boatPart/bateau", {
	DataType = "HARBOUR_COMP_WATERLINE",
	Enabled = true,
        RandomPath = true
    })
    harbour:registerPrefabComponent("models/boat2.fbx/Prefab/harbour/boatPart/bateau", {
	DataType = "COMP_GROUNDED",
	GroundToWater = true
    })

-- Register IDs for all prefab nodes referenced here
harbour:registerAssetId("models/boat2.fbx/Prefab/harbour/boatStaticPart", "HARBOUR_BOAT_STATIC_PREFAB")

harbour:register({
	DataType = "BUILDING_PART",
	Id = "HARBOUR_BOAT_STATIC_PART",
	Name = "HARBOUR_BOAT_STATIC_NAME",
	Description = "HARBOUR_BOAT_STATIC_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "HARBOUR_BOAT_STATIC_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = 5 }
		}
	}
})
    harbour:registerPrefabComponent("models/boat2.fbx/Prefab/harbour/boatStaticPart", {
	DataType = "COMP_GROUNDED",
	GroundToWater = true
    })

-- Register the dock part
-- Apply building asset processor
harbour:registerAssetProcessor("models/dock.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

harbour:registerAssetId("models/dock.fbx/Prefab/harbour/dockPart", "HARBOUR_DOCK_PREFAB")
harbour:registerAssetId("models/dock.fbx/Prefab/harbour/pontonPart", "HARBOUR_PONTOON_PREFAB")

harbour:register({
	DataType = "BUILDING_PART",
	Id = "HARBOUR_DOCK_PART",
	Name = "HARBOUR_DOCK_NAME",
	Description = "HARBOUR_DOCK_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "HARBOUR_DOCK_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = 5 }
		}
	}
})

harbour:register({
	DataType = "BUILDING_PART",
	Id = "HARBOUR_PONTOON_PART",
	Name = "HARBOUR_PONTOON_NAME",
	Description = "HARBOUR_PONTOON_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "HARBOUR_PONTOON_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = 3 }
		}
	}
})

--------------------------------------------------------------------------
-- Override building part components properties (generated by the building asset processor) to add building zones
harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/dockPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 16, 4 }
})

harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/pontonPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 4 }
})

    harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/dockPart/group1", {
	DataType = "COMP_GROUNDED",
	GroundToWater = true
    })
    harbour:registerPrefabComponent("models/dock.fbx/Prefab/harbour/pontonPart/group2", {
	DataType = "COMP_GROUNDED",
	GroundToWater = true
    })

--------------------------------------------------------------------------
-- Configure all PLATFORM colliders
harbour:configurePrefabFlagList("models/boat2.fbx/Prefab/harbour/boatPart", { "PLATFORM" })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/dockPart", { "PLATFORM" })
harbour:configurePrefabFlagList("models/dock.fbx/Prefab/harbour/pontonPart", { "PLATFORM" })
